function [Ndet, Ndetprct, Is, C]=DetectBreaksLoc(C, DetPRCT, Fs, tmax)
%% Function to detects breaking waves associated pattens location (instances in time)
% This function recieves Coeffs matrix (a result of Wavelets Transfrom) and finds
% instancies of max. energy (pattern matching) according to the set threshold
%
% Input arguments:
% C - is the wavelet analysis coefficients matrix (rows time, columns "freqs")
% DetPRCT - is the % threshold (%Emax value energy matching)
% Fs - is the sampling frequency
% tmax - is the vector containing time values corresponding waves crests
% 
% Outputs arguments:
% Ndet - is the total count of detected breakers
% Ndetprct - Cis the count of detected breakers in terms of % of total
%   crests in the ensemble
% Is - is the vector of indicies corresponding time vector, denoting times of the detected breaking crests
% C - is the proccessed matrix of coefs. after apllication fo the threshold
%
% Dan Liberzon, 2019, liberzon@technion.ac.il



%% Zero all values lower than the threshold %
Cm=max(C(:)); C(C<DetPRCT*Cm)=0;

%% Now seek the detected patterns locations
dT=median(diff(tmax)); % 1/mean frequency (main) at each channel
Cc=mean(C);

I=find(Cc~=0); N=length(I);
% seek and find mid. locations
St=[]; Is=[];
for k=1:N-1
    if diff(I(k:k+1))./Fs>0.5*dT
        St=[St, I(k)];
        Is=[Is, mean(St)]; St=[];
    else
        St=[St, I(k)];
    end
end
Is=[Is, mean(St)]; % last one to detect

Ndet=length(Is); % Count the detected breakers
Ndetprct=100*Ndet./length(tmax); % % out of all detected crests (tmax)
end