function[t,fr]=FreqVarHilbertClean(data, Fs)
%% Function to obtain teh instantanious freqeuncy variations, by Hilbert Transform.
% ref: https://doi.org/10.1061/(ASCE)0733-950X(2002)128:2(72)
%
% data - is teh time series vector (one column)
% Fs - is the data sampling frequency [Hz]
% t - is the resulted time vector
% fr - is the computed variations of the instantanious frequency [Hz], in one column
%
% Dan Liberzon, 2019, liberzon@technion.ac.il

%% time vector  
dt=1/Fs;
npts=length(data); % number of data points 
t=(0:npts-1).*dt; 
%% Hilbert transform and the rest
Hdat=hilbert(data);% Calculate the analytical function
theta=angle(Hdat);      % Calculate the phase in radians
theta=unwrap(theta);    % Unwrap the phase
fr=[diff(theta)./dt;0];     % Compute the instantanious frequency variation
end