function [Coefs, fsc]=PatternRecWavelet(sig, Fs, FN, Noct)
%% Function to process the given sig (inst. freq.) with teh given FN# wavelet for pattern matching recognition
% sig - is the signal to process, single column vector
% Fs - is the sig sampling frequency [Hz]
% FN - is the name of the file containing the (mother)WaveLet, for example 'FN2.mat'
% Noct - is the number of octaves (2^n)
%
% Coefs - is teh 2D array of wavelet transform result coefficients
% fsc - the the corresponding vector of pseudo-frequencies [Hz]
%
% Dan Liberzon, 2019, liberzon@technion.ac.il


%% Create approp. names of wavelet
il=find(FN=='.')-1;
WName=['Adap', FN(1:il)];
Wname=['adpf', FN(il)];
WFile=['adp_' FN(1:il) '.mat'];


%% Check if the wavelet is already loaded:

WF=wavemngr('read'); wcomp=[];
for w=2:size(WF,1)-1 % loop on wavelets names
    wcomp=[wcomp, strcmp(WName,WF(w,1:6))];
end
load(FN);
FL=length(eval(FN(1:il)));
if ~any(wcomp) % meaning the wavelet is not loaded previously
    
    wavemngr('add',WName,Wname,4,'',WFile,[0 1]);
end

%% Call CWT (continious wavelets transfrom) and return the results:
stepSIG = 1/Fs;
stepWAV = 1/Noct;
scales  = (1:2*FL/2)*stepSIG;
WAV = {Wname,stepWAV};
SIG = {sig,stepSIG};

Coefs=cwt(SIG,scales,WAV);

fsc=scal2frq(scales,Wname);
end
