function [fr_c, tmax, maxe, t_pos, t_neg]=SigCondit(eta, fr, Fs, fc)
%% Function to conduct signals (eta nd F) pre-conditioning 
% The follwoing are performed:
% 1. Detection of crests instances
% 2. Zeroing of F at periods of negative surface elevation 
% 3. Amplification according to eta
% 4. LP filtering if requested

% eta - is the surafce elevation fluctuations data, column vector
% fr - is the variations of instantanious frequency as returned by the HilbertTransform function
% Fs - is the data sampling frequency

% Varargin expected inputs - FIltering option. If not used no filtering is
% performed
% fc - is the Low-Pass filtering cut of frequency
%
% Outputs:
% fr_c - is the conditioned signal of instantanious frequency variations
% tmax - is the vector of actual times of crests in eta
% maxe - is the vector of crests surface levation values in eta
% t_pos and t_neg - are the vectors of times of detected posistive and
%   negative zero crossings in the surface elevation fluctutaions series,
%   correspondingly
%
% Dan Liberzon, 2019, liberzon@technion.ac.il


%% Pre-conditioning
eta=eta-mean(eta);
if length(eta)~=length(fr)
    error('Error: something went wrong eta and fr lengths are different!!!1');
end
t=1/Fs.*[0:length(eta)-1];
%% calling the LowPass filter if requested
if fc
    [fr]=LowPass(fr, Fs, fc);
end

%% Detecting crests
[pos_index, neg_index] = ZeroCross(eta);
for i=1:1:(length(pos_index)-1)
    [maxe(i), ind]=(max(eta(pos_index(i):pos_index(i+1))));
    tmax(i)=t(pos_index(i)+ind);
end
tmax=tmax'; maxe=maxe';
t_pos=t(pos_index)'; t_neg=t(neg_index)';

%% Amplification by eta
 fr_c=fr.*eta;

%% Zero fr at eta negative values
 fr_c(eta<=0)=0;
end
