function [pos_index,neg_index] = ZeroCross (data)
% function to obtain indiexes in which the input signal (fluctuating around 0 mean) is crossing the 0
% pos_index- negative to positive crossing
% neg_index- positive to negative crossing
%
% the pos_index(start) will be smaller than neg_index(start)
%
% Input arguments
% data - is the vector containing periodic signal with zero mean value

% Output arguments:
% pos_index- the negative to positive crossings indexes
% neg_index- the positive to negative crossing indexes

% Dan Liberzon, 2019, liberzon@technion.ac.il


r=length(data);         % in order to know how long is the data
pos_index=[];           % empty vector
neg_index=[];           % empty vector

for i=1:r-1
    if (data(i+1)*data(i))<0
        if data(i+1)>data(i)
            pos_index=[pos_index,i];
        else
            neg_index=[neg_index,i];
        end
    end
end

if length(pos_index)>length(neg_index)
    a=length(pos_index)-length(neg_index);
    if a>1
        for i=1:a
            pos_index(end+1-i)=[];
        end
    else
        return
    end
end

if length(pos_index)<length(neg_index)
    b=length(neg_index)-length(pos_index);
    for i=1:(b+1)
        neg_index(end+1-i)=[];
    end
end

if neg_index(1)<pos_index(1)
    neg_index(1)=[];
    pos_index(end)=[];
end
end

